@@ -35,7 +35,7 @@
 * async fn demo() -> Result<()>{
 * // set up the LCD client
 * let gas_opts = GasOptions::create_with_gas_estimate("50ukrw",1.4)?;
-* let terra = Terra::lcd_client("https://tequila-lcd.terra.dev/", "tequila-0004", &gas_opts).await?;
+* let terra = Terra::lcd_client("https://tequila-lcd.terra.dev/", "tequila-0004", &gas_opts,None).await?;
 * // generate a private key
 * let secp = Secp256k1::new();
 * let from_key = PrivateKey::from_words(&secp,"your secret words")?;
@@ -46,24 +46,14 @@
 * let send: MsgSend = MsgSend::create(from_account, String::from("terra1usws7c2c6cs7nuc8vma9qzaky5pkgvm2uag6rh"), vec![coin]);
 * // generate the transaction & calc fees
 * let messages: Vec<Box<dyn Msg>> = vec![Box::new(send)];
-* let std_fee = terra.calc_fees(&messages).await?;
-* let auth_result: AuthAccountResult =
-*                terra.auth().account(&from_public_key.account()?).await?;
-* let account_number = auth_result.result.value.account_number;
-* let std_sign_msg = StdSignMsg {
-*                 chain_id: terra.chain_id.to_string(),
-*                 account_number,
-*                 sequence: auth_result.result.value.sequence,
-*                 fee: std_fee,
-*                 msgs: messages,
-*                 memo: "Luna to the Moon!".to_string(),
-*  };
-*
-* // Sign it
-*  let js = serde_json::to_string(&std_sign_msg)?;
-*  let sig = from_key.sign(&secp, &js)?;
-*  let sigs: Vec<StdSignature> = vec![sig];
-*
+* let (std_sign_msg, sigs) = terra
+*                .generate_transaction_to_broadcast(
+*                    &secp,
+*                    &from_key,
+*                    &messages,
+*                    None
+*                )
+*                .await?;
 * // send it out
 *  let resp = terra.tx().broadcast_sync(&std_sign_msg, &sigs).await?;
 *  match resp.code {
@@ -79,7 +69,8 @@
 * }
 * ```
 */
-mod client;
+/// APIs
+pub mod client;
 /// Error Messages
 pub mod errors;
 mod keys;
